@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2019 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2020 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -77,8 +77,8 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 
 	private Battle battle;
 	private RobotStatistics statistics;
-	private final TeamPeer teamPeer;
 	private final RobotSpecification robotSpecification;
+	private final TeamPeer teamPeer;
 
 	private IHostingRobotProxy robotProxy;
 	private AtomicReference<RobotStatus> status = new AtomicReference<RobotStatus>();
@@ -138,7 +138,7 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 	private final BoundingRectangle boundingBox;
 	private final RbSerializer rbSerializer;
 
-	public RobotPeer(Battle battle, IHostManager hostManager, RobotSpecification robotSpecification, int duplicate, TeamPeer team, int robotIndex) {
+	public RobotPeer(Battle battle, IHostManager hostManager, RobotSpecification robotSpecification, String suffix, TeamPeer team, int robotIndex) {
 		super();
 
 		this.battle = battle;
@@ -172,7 +172,7 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 			teamIndex = team.getTeamIndex();
 		}
 
-		this.statics = new RobotStatics(robotSpecification, duplicate, isTeamLeader, battleRules, teamName, teamMembers,
+		this.statics = new RobotStatics(robotSpecification, suffix, isTeamLeader, battleRules, teamName, teamMembers,
 				robotIndex, teamIndex);
 		this.statistics = new RobotStatistics(this, battle.getRobotsCount());
 
@@ -270,10 +270,6 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 		return statics.getTeamIndex();
 	}
 
-	public int getContestantIndex() {
-		return getTeamIndex() >= 0 ? getTeamIndex() : getRobotIndex();
-	}
-
 	// -------------------
 	// status 
 	// -------------------
@@ -1404,7 +1400,7 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 	 * Updates the robots movement.
 	 *
 	 * This is Nat Pavasants method described here:
-	 *   http://robowiki.net/wiki/User:Positive/Optimal_Velocity#Nat.27s_updateMovement
+	 *   https://robowiki.net/wiki/User:Positive/Optimal_Velocity#Nat.27s_updateMovement
 	 */
 	private void updateMovement() {
 		double distance = currentCommands.getDistanceRemaining();
@@ -1460,7 +1456,7 @@ public final class RobotPeer implements IRobotPeerBattle, IRobotPeer {
 	 * @return the new velocity based on the current velocity and distance to move
 	 * 
 	 * This is Patrick Cupka (aka Voidious), Julian Kent (aka Skilgannon), and Positive's method described here:
-	 *   http://robowiki.net/wiki/User:Voidious/Optimal_Velocity#Hijack_2
+	 *   https://robowiki.net/wiki/User:Voidious/Optimal_Velocity#Hijack_2
 	 */
 	private double getNewVelocity(double velocity, double distance) {
 		if (distance < 0) {
