@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2019 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2020 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -584,7 +584,7 @@ public class RobotItem extends RobotSpecItem implements IRobotItem {
 		return path;
 	}
 
-	public RobotSpecification createRobotSpecification(RobotSpecification battleRobotSpec, String teamId) {
+	public RobotSpecification createRobotSpecification(RobotSpecification battleRobotSpec, String teamName) {
 		RobotSpecification specification;
 
 		if (battleRobotSpec != null) {
@@ -592,8 +592,8 @@ public class RobotItem extends RobotSpecItem implements IRobotItem {
 		} else {
 			specification = createRobotSpecification();
 		}
-		if (teamId != null) {
-			HiddenAccess.setTeamId(specification, teamId);
+		if (teamName != null) {
+			HiddenAccess.setTeamName(specification, teamName);
 		}
 		return specification;
 	}
